pub struct Request { /* private fields */ }Expand description
Implementations
sourceimpl Request
impl Request
sourcepub fn matches(&self, resource: &str) -> bool
pub fn matches(&self, resource: &str) -> bool
Test if resource is included in the requested hash check.
sourcepub fn unwinder<'a>(&self, manager: &'a Manager) -> ResponseHashRewinder<'a>
pub fn unwinder<'a>(&self, manager: &'a Manager) -> ResponseHashRewinder<'a>
Get an unwinder to unwind the resources you will add to the map before calling
crate::Manager::apply_hash_check_reply.
If you start doing this now, before getting the response, keep in mind you have to check
Response::different_cutoff. If that returns true, you have to call
Response::unwinder and start the process over again.