pub struct Response { /* private fields */ }Expand description
A response to Request.
Contains the Self::hashes for all the resources the sender wants.
Eq implementation
If the receiver is the same, this is considered equal. Only one of these conversations should be communicated at once, therefore the filter doesn’t matter.