agde::hash_check

Struct ResponseBuilder

source
pub struct ResponseBuilder<'a>(/* private fields */);
Builder struct for Response.

Implementations

source

impl<'a> ResponseBuilder<'a>

source

pub fn insert(&mut self, resource: String, hash: ResponseHash)

It’s a logic error to pass a resource that isn’t included in the Request::matches.

source

pub fn unwinder(&mut self) -> &mut Unwinder<'a>

Unwind the resources before creating a hash for Self::insert.

Call this for every resource.

source

pub fn finish(self) -> Response

Get the built Response.

source

pub fn matches(&self, resourc