agde::hash_check

Struct ResponseHashRewinder

source
pub struct ResponseHashRewinder<'a>(/* private fields */);
A struct used to rewind resources before hashing them to call crate::Manager::apply_hash_check_reply.

Implementations

source

impl<'a> ResponseHashRewinder<'a>

source

pub fn unwinder(&mut self) -> &mut Unwinder<'a>

Unwind the resources before creating a hash for crate::Manager::apply_hash_check_reply.

Call this for every resource.