pub struct ResponseBuilder<'a>(/* private fields */);Expand description
Builder struct for Response.
Implementations
sourceimpl<'a> ResponseBuilder<'a>
impl<'a> ResponseBuilder<'a>
sourcepub fn insert(&mut self, resource: String, hash: ResponseHash)
pub fn insert(&mut self, resource: String, hash: ResponseHash)
It’s a logic error to pass a resource that isn’t included in the Request::matches.
sourcepub fn unwinder(&mut self) -> &mut Unwinder<'a>
pub fn unwinder(&mut self) -> &mut Unwinder<'a>
Unwind the resources before creating a hash for Self::insert.
Call this for every resource.