pub struct ResponseHashRewinder<'a>(/* private fields */);Expand description
A struct used to rewind resources before hashing them to call
crate::Manager::apply_hash_check_reply.
Implementations
sourceimpl<'a> ResponseHashRewinder<'a>
impl<'a> ResponseHashRewinder<'a>
sourcepub fn unwinder(&mut self) -> &mut Unwinder<'a>
pub fn unwinder(&mut self) -> &mut Unwinder<'a>
Unwind the resources before creating a hash for crate::Manager::apply_hash_check_reply.
Call this for every resource.