pub struct ResponseHasher(/* private fields */);Expand description
A hash builder for adding the hashed signature of a resource.
Should be created, written to and the
added when all the data is written.
Implementations
sourceimpl ResponseHasher
impl ResponseHasher
sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new, empty hasher.
Add data using Self::write.
sourcepub fn write(&mut self, bytes: &[u8])
pub fn write(&mut self, bytes: &[u8])
Write data from resource to the internal hasher.
After all the data for one resource is written, call ResponseBuilder::insert.
sourcepub fn finish(self) -> ResponseHash
pub fn finish(self) -> ResponseHash
Digest this hash.